@@ -27,7 +27,7 @@ class Boot:
 
     def __select_partition(self):
         for disk in self.disks:
-            if self.system.disk_available(disk):
+            if self.system.disk_is_ready(disk):
                 print "Disk found: {}".format(disk)
                 return disk
         return None
@@ -35,11 +35,11 @@ class Boot:
     def sync_time(self):
         retry = 0
         while retry < self.max_retries:
-            if self.system.network_is_up():
+            if self.system.network_is_up('eth0'):
                 self.system.sync_time()
                 return
             retry += 1
-            print "saiting for network to come up ({})".format(retry)
+            print "waiting for network to come up ({})".format(retry)
             sleep(1)
 
         print "network is still down"
