@@ -1,3 +1,4 @@
+from os import listdir
 from subprocess import check_output
 
 
@@ -6,9 +7,12 @@ class System:
     def __init__(self):
         pass
 
-    def disk_available(self, disk):
+    def disk_is_ready(self, disk):
         return self.run(['blkid', disk])
 
+    def disks_available(self):
+        return check_output(['blkid', '-o', 'device']).splitlines()
+
     def mount_disk(self, disk, directory):
         return self.run(['mount', disk, directory])
 
@@ -17,17 +21,28 @@ class System:
         chown = ['chown', '-R', '{}:{}'.format(user, user), directory]
         return self.run(chmod) and self.run(chown)
 
-    def network_is_up(self):
-        with open("/sys/class/net/eth0/operstate", 'r') as f:
-            return f.read() == 'up'
+    def network_is_up(self, name):
+        with open("/sys/class/net/{}/operstate".format(name), 'r') as f:
+            status = f.read().strip()
+            print "{}: {}".format(name, status)
+            return status == 'up'
+
+    def networks_available(self):
+        return listdir("/sys/class/net")
 
     def sync_time(self):
         return self.run(['ntpdate', '-u', 'pool.ntp.org'])
 
     def run(self, *args):
         try:
+            print("running: '{}'".format(self.srepr(*args)))
             print check_output(*args)
             return True
         except Exception as e:
             print e.message
-            return False
\ No newline at end of file
+            return False
+
+    def srepr(self, list):
+        if isinstance(list, basestring):
+            return list
+        return " ".join(list)
\ No newline at end of file
